@@ -3,51 +3,33 @@
  * @brief Header file for ChunkWriter class
  * @author Jonathan Thomas <jonathan@openshot.org>
  *
- * @section LICENSE
- *
- * Copyright (c) 2008-2014 OpenShot Studios, LLC
- * <http://www.openshotstudios.com/>. This file is part of
- * OpenShot Library (libopenshot), an open-source project dedicated to
- * delivering high quality video editing and animation solutions to the
- * world. For more information visit <http://www.openshot.org/>.
- *
- * OpenShot Library (libopenshot) is free software: you can redistribute it
- * and/or modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * OpenShot Library (libopenshot) is distributed in the hope that it will be
- * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with OpenShot Library. If not, see <http://www.gnu.org/licenses/>.
+ * @ref License
  */
 
+// Copyright (c) 2008-2019 OpenShot Studios, LLC
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef OPENSHOT_CHUNK_WRITER_H
 #define OPENSHOT_CHUNK_WRITER_H
 
 #include "ReaderBase.h"
 #include "WriterBase.h"
 #include "FFmpegWriter.h"
+#include "CacheMemory.h"
+#include "Json.h"
 
 #include <cmath>
 #include <ctime>
 #include <iostream>
 #include <fstream>
-#include <omp.h>
-#include <QtCore/qdir.h>
-#include <stdio.h>
+#include <cstdio>
 #include <sstream>
 #include <unistd.h>
-#include "CacheMemory.h"
-#include "Exceptions.h"
-#include "Json.h"
+#include <omp.h>
+#include <QtCore/QDir>
 
 
-using namespace std;
-
 namespace openshot
 {
 	/**
@@ -80,27 +62,27 @@ namespace openshot
 	class ChunkWriter : public WriterBase
 	{
 	private:
-		string path;
+		std::string path;
 		int64_t chunk_count;
 		int64_t chunk_size;
 		int64_t frame_count;
 		bool is_open;
 		bool is_writing;
-		ReaderBase *local_reader;
-		FFmpegWriter *writer_thumb;
-		FFmpegWriter *writer_preview;
-		FFmpegWriter *writer_final;
+		openshot::ReaderBase *local_reader;
+		openshot::FFmpegWriter *writer_thumb;
+		openshot::FFmpegWriter *writer_preview;
+		openshot::FFmpegWriter *writer_final;
 	    std::shared_ptr<Frame> last_frame;
 	    bool last_frame_needed;
-	    string default_extension;
-	    string default_vcodec;
-	    string default_acodec;
+	    std::string default_extension;
+	    std::string default_vcodec;
+	    std::string default_acodec;
 
 		/// check for chunk folder
-		void create_folder(string path);
+		void create_folder(std::string path);
 
 		/// get a formatted path of a specific chunk
-		string get_chunk_path(int64_t chunk_number, string folder, string extension);
+		std::string get_chunk_path(int64_t chunk_number, std::string folder, std::string extension);
 
 		/// check for valid chunk json
 		bool is_chunk_valid();
@@ -113,7 +95,7 @@ namespace openshot
 		/// @brief Constructor for ChunkWriter. Throws one of the following exceptions.
 		/// @param path The folder path of the chunk file to be created
 		/// @param reader The initial reader to base this chunk file's meta data on (such as fps, height, width, etc...)
-		ChunkWriter(string path, ReaderBase *reader);
+		ChunkWriter(std::string path, openshot::ReaderBase *reader);
 
 		/// Close the writer
 		void Close();
@@ -133,7 +115,7 @@ namespace openshot
 
 		/// @brief Add a frame to the stack waiting to be encoded.
 		/// @param frame The openshot::Frame object that needs to be written to this chunk file.
-		void WriteFrame(std::shared_ptr<Frame> frame);
+		void WriteFrame(std::shared_ptr<openshot::Frame> frame);
 
 		/// @brief Write a block of frames from a reader
 		/// @param start The starting frame number to write (of the reader passed into the constructor)
@@ -144,7 +126,7 @@ namespace openshot
 		/// @param reader The reader containing the frames you need
 		/// @param start The starting frame number to write
 		/// @param length The number of frames to write
-		void WriteFrame(ReaderBase* reader, int64_t start, int64_t length);
+		void WriteFrame(openshot::ReaderBase* reader, int64_t start, int64_t length);
 
 	};
 
